@@ -8,7 +8,7 @@
  ****************************************************************************/
 
 /*
- * <$Id: ne_mesg.c,v 3.48 2002/12/10 22:31:18 dillema Exp $>
+ * <$Id: ne_mesg.c,v 3.49 2005/07/04 09:09:22 dillema Exp $>
  */
 
 #include "totd.h"
@@ -59,7 +59,7 @@ int mesg_make_query (u_char *qname, uint16_t qtype, uint16_t qclass,
 
 	/* write qname */
 	if (T.debug > 4)
-		syslog (LOG_DEBUG, "%s: qname offset = %d", fn, ucp - buf);
+		syslog (LOG_DEBUG, "%s: qname offset = %zd", fn, ucp - buf);
 
 	i = dname_copy (qname, ucp, buflen - written_len);
 	if (i < 0)
@@ -70,7 +70,7 @@ int mesg_make_query (u_char *qname, uint16_t qtype, uint16_t qclass,
 
 	/* write qtype / qclass */
 	if (T.debug > 4)
-		syslog (LOG_DEBUG, "%s: qtype/qclass offset = %d",
+		syslog (LOG_DEBUG, "%s: qtype/qclass offset = %zd",
 			fn, ucp - buf);
 
 	written_len += sizeof (uint16_t) * 2;
@@ -226,7 +226,7 @@ int mesg_write_rrset_list (G_List *rrls, u_char *msg, u_char *msg_tail,
 			*cnt = htons (us);
 
 			if (T.debug > 4)
-				syslog (LOG_DEBUG, "%s: now counter = %d",
+				syslog (LOG_DEBUG, "%s: now counter = %zd",
 					fn, us);
 		}
 	}
