@@ -8,13 +8,21 @@
  ****************************************************************************/
 
 /*
- * <$Id: protos.h,v 3.60 2002/12/11 16:39:50 dillema Exp $>
+ * <$Id: protos.h,v 3.62 2005/01/27 15:29:33 dillema Exp $>
  */
 
 #if !HAVE_STRLCPY
 size_t strlcpy(char *, const char *, size_t);
+#endif
+#if !HAVE_STRLCAT
 size_t strlcat(char *, const char *, size_t);
 #endif
+#if !HAVE_DAEMON
+int daemon(int, int);
+#endif
+#if !HAVE_DAEMON
+int inet_aton(const char *, struct in_addr *);
+#endif
 
 RRset *search_name (G_List *, char *, int, int);
 char *sprint_inet(struct sockaddr *, char *);
@@ -193,3 +201,8 @@ void conv_scoped_list (G_List *);
 int conv_is_scoped_ptr (u_char *, int);
 void conv_scoped_ptr (G_List *, u_char *);
 void conv_scoped_ptr_rq (u_char *);
+#ifdef SWILL
+void print_stats(FILE *);
+void add_prefix(FILE *);
+void del_prefix(FILE *);
+#endif
