@@ -8,7 +8,7 @@
  ****************************************************************************/
 
 /*
- * <$Id: read_config.c,v 3.36 2002/12/11 16:39:50 dillema Exp $>
+ * <$Id: read_config.c,v 3.38 2005/01/29 18:51:36 dillema Exp $>
  */
 
 #include "totd.h"
@@ -90,6 +90,19 @@ int read_config (char *config_file) {
 				} else
 					syslog (LOG_INFO, "prefix %d added: %s", T.prefixnum, args[1]);
 			}
+		} else if (!strcasecmp (args[0], "allow")) {
+			if (argcnt != 2) {
+				syslog (LOG_ERR, "line %d: invalid format: allow <IP address>", linenum);
+				errcnt++;
+			} else {
+#ifdef SWILL
+				if (T.http_port) {
+					swill_allow(args[1]);
+					syslog (LOG_INFO, "allow http connects from %s", args[1]);
+				} else
+#endif
+					syslog (LOG_INFO, "NOTE: http support not enabled!!!");
+			}
 		} else if (!strcasecmp (args[0], "retry")) {
 			if (argcnt != 2) {
 				syslog (LOG_ERR, "line %d: invalid format: retry <seconds>", linenum);
