@@ -8,12 +8,14 @@
  ****************************************************************************/
 
 /*
- * <$Id: request.c,v 3.95 2002/12/09 18:41:43 dillema Exp $>
+ * <$Id: request.c,v 3.99 2005/07/04 09:09:22 dillema Exp $>
  */
 
 #include "totd.h"
 
+#ifdef STF
 static void collect_ns_socks (Context *);
+#endif
 static void cname_without_crecord (G_List *, u_char *);
 
 /*
@@ -153,6 +155,7 @@ int request_start (Context *cont, int tcp) {
 int do_forward(struct context *parent, u_char *qname, uint16_t qclass,
 	       uint16_t qtype, int tcp) {
 	const char *fn = "do_forward()";
+        static u_char buf[MAX_STREAM];     /* Buffer for TCP/UDP messages */
 	u_char str[MAX_DNAME];
 	Context *cont;
 
@@ -185,11 +188,11 @@ int do_forward(struct context *parent, u_char *qname, uint16_t qclass,
 		qname = (parent->mesg.p + sizeof (Mesg_Hdr));
 
 	cont->mesg_len = mesg_make_query (qname, qtype, qclass, cont->q_id, 1,
-					  T.MSG_Buf, MAX_STREAM);
+					  buf, sizeof(buf));
 
 	if (cont->mesg_len < 0) {
-                syslog (LOG_ERR, "%s: failed to keep query in %d bytes",
-			fn, MAX_STREAM);
+                syslog (LOG_ERR, "%s: failed to keep query in %zd bytes",
+			fn, sizeof(buf));
 		return (request_abort (cont, -1));
 	}
 
@@ -199,7 +202,7 @@ int do_forward(struct context *parent, u_char *qname, uint16_t qclass,
 		return (request_abort (cont, -1));
 	}
 
-	memcpy (cont->mesg.p, T.MSG_Buf, cont->mesg_len);
+	memcpy (cont->mesg.p, buf, cont->mesg_len);
         cont->wp = cont->mesg.p;
 
 	if (tcp == 0) {
@@ -540,10 +543,10 @@ found for 6to4 PTR name: %s", fn, astr);
 		strlcpy(qname, cont->qname, MAX_DNAME);
 		qtype = RT_PTR;
 		break;
-#endif
 	default:
 		break;
 	}
+#endif
 
 	syslog (LOG_DEBUG, "%s: current work state: %d", fn, cont->work_state);
 
@@ -551,7 +554,7 @@ found for 6to4 PTR name: %s", fn, astr);
 		/*
 		 * We should be finished then... unless we only got a CNAME
 		 * record in our answers and no address record with it to
-		 * resolve it. In * that case, we need to do another query to
+		 * resolve it. In that case, we need to do another query to
 		 * our forwarder to resolve it properly.
 		 *
 		 * Note that we only follow CNAME's for the actual answer
@@ -566,7 +569,7 @@ found for 6to4 PTR name: %s", fn, astr);
 			 * if so, should we follow it? standard (RFC) only
 			 * allows a single CNAME, but CNAME chaining is rather
 			 * common in practice. We follow chains a bit, but
-			 * avoid following an CNAME loop by limiting its length.
+			 * avoid following a CNAME loop by limiting its length.
 			 */
 			if (cont->cname_links++ > SEARCH_CNAME_LEVEL) {
 				syslog (LOG_DEBUG, "%s: exceeded max number \
@@ -747,6 +750,7 @@ int request_finish (Context *cont) {
 	return 0; /* SUCCESS */
 }
 
+#ifdef STF
 /*
  * Expects list of NS records in AN section of given context.
  * It searches for address records (A or AAAA) in the AR section of the
@@ -909,6 +913,7 @@ void collect_ns_socks (Context *cont) {
 
   	return;
 }
+#endif
 
 void cname_without_crecord (G_List *an_list, u_char *cname) {
         char *fn = "cname_without_crecord()";
