@@ -8,13 +8,13 @@
  ****************************************************************************/
 
 /*
- * <$Id: totd.c,v 3.66 2003/01/27 16:22:46 dillema Exp $>
+ * <$Id: totd.c,v 3.74 2005/02/02 11:10:31 dillema Exp $>
  */
 
 #include "totd.h"
 
 struct ToT T;
-char *version = "Trick or Treat Daemon (totd) version 1.4-beta";
+char *version = "Trick or Treat Daemon (totd) version 1.5";
 
 void usage () {
 	printf ("%s\n\
@@ -30,6 +30,7 @@ Usage: totd [-6|-no6|-4|-no4|-64|-dn|-v|-q|-p <prefix>|-c <filename>]\n\
 -g <group>  : groupname or gid totd should run at, after startup\n\
 -t <dir>    : put totd in <dir> chroot() cage\n\
 -p <prefix> : a prefix to use for totd tricks; more than one allowed\n\
+-http-port <port> : port we listen on for http requests (default = 6464)\n\
 -c <file>   : specify alternative totd configfile, default=%s\n\
 \n\
 default   : IPv6 is %s and IPv4 is %s\n\n\
@@ -73,6 +74,7 @@ int main (int argc, char **argv) {
 	T.stf = 0;
 	T.retry_interval = 300;
 	T.port = PORT_SRV;
+	T.http_port = 0;
 	T.wildcard = 1;
 	T.Fwd_list = NULL;
 	T.pidfile = TOT_PID_FILE;
@@ -95,12 +97,6 @@ int main (int argc, char **argv) {
 			/* debug option */
 			T.debug = atoi(&argv[i][2]);
 			syslog (LOG_INFO, "debug level %d enabled", T.debug);
-#ifdef NDEBUG
-			if (T.debug > 1) {
-				syslog (LOG_INFO, "NDEBUG was defined at compile time, so not much more debug info available");
-				syslog (LOG_INFO, "Comment NDEBUG in config.h and recompile to enable verbose debugging");
-			}
-#endif
 		} else if (!strcmp (argv[i], "-6"))
 			T.ip6 = 1;
 		else if (!strcmp (argv[i], "-4"))
@@ -118,6 +114,13 @@ int main (int argc, char **argv) {
 			    syslog (LOG_ERR, "invalid prefix on command line: %s", argv[++i]);
 			    usage(1);
 			}
+		}
+		else if (!strcmp (argv[i], "-http-port")) {
+			T.http_port = atoi(argv[++i]);
+			if (!T.http_port) {
+				syslog (LOG_ERR, "invalid portnumer: %s", argv[++i]);
+				usage(1);
+			}
 		} else if (!strcmp (argv[i], "-u"))
 			T.user = strdup(argv[++i]);
 		else if (!strcmp (argv[i], "-g"))
@@ -224,6 +227,14 @@ to: %s", T.user);
                 }
 	}
 
+#ifdef SWILL
+  	/* Initialize the SWILL server */
+	if (T.http_port) {
+  		swill_init(T.http_port);
+		syslog (LOG_INFO, "Listening on [*]:%d for http requests", T.http_port);
+		swill_deny("");
+	}
+#endif
 	/*
 	 * read in config file
 	 * possibly overriding defaults and command line options
@@ -417,6 +428,15 @@ in your config file or remove `scoped' keyword");
 		fclose (pid_fp);
 	}
 
+#ifdef SWILL
+	if (T.http_port) {
+		if (T.debug) swill_log(stderr);
+		swill_title("Trick or Treat DNS Proxy");
+        	swill_handle("index.html", print_stats, 0);
+        	swill_handle("add-prefix.html", add_prefix, 0);
+        	swill_handle("del-prefix.html", del_prefix, 0);
+	}
+#endif
 	syslog (LOG_INFO, "totd started");
 	totd_eventloop ();
 	return (totd_exit (0));
@@ -428,7 +448,6 @@ void totd_eventloop (void) {
 	fd_set fd_read, fd_write;
 	int max_fd, fdnum, i;
 	time_t next_timeout;
-
 #ifdef DBMALLOC
 	unsigned long histid1, histid2, orig_size, current_size;
 
@@ -459,22 +478,34 @@ void totd_eventloop (void) {
 		}
 #endif
 
+#ifdef SWILL
+		if (T.http_port) swill_poll();
+#endif
 		/* signal event */
 		ev_signal_process ();
 
 		/* timeout event */
-		next_timeout = ev_timeout_process ();
-		if (!next_timeout) {
-			if (T.debug > 2)
-				syslog (LOG_DEBUG, "no timeouts at present");
-			tvp = NULL;
-		} else {
-			tv_out.tv_usec = 0;
-			tv_out.tv_sec = next_timeout - time (NULL);
+#ifdef SWILL
+		if (T.http_port) {
+			tv_out.tv_usec = 500;
+			tv_out.tv_sec = 0;
 			tvp = &tv_out;
-			if (T.debug > 2)
-				syslog (LOG_DEBUG, "next timeout after %ld s.",
-					tv_out.tv_sec);
+		} else
+#endif
+		{
+			next_timeout = ev_timeout_process ();
+			if (!next_timeout) {
+				if (T.debug > 2)
+					syslog (LOG_DEBUG, "no timeouts at present");
+				tvp = NULL;
+			} else {
+				tv_out.tv_usec = 0;
+				tv_out.tv_sec = next_timeout - time (NULL);
+				tvp = &tv_out;
+				if (T.debug > 2)
+					syslog (LOG_DEBUG, "next timeout after %ld s.",
+						tv_out.tv_sec);
+			}
 		}
 
 		/* get FD_SET for now */
