@@ -8,7 +8,7 @@
  ****************************************************************************/
 
 /*
- * <$Id: totd.h,v 3.37 2003/09/17 11:27:42 dillema Exp $>
+ * <$Id: totd.h,v 3.41 2005/01/29 18:51:36 dillema Exp $>
  */
 
 #ifndef TOT_H
@@ -18,20 +18,30 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
+#endif
 #include <errno.h>
 #include <signal.h>
+#ifdef HAVE_SYSLOG_H
 #include <syslog.h>
+#endif
 #include <string.h>
 #include <assert.h>
 #include <netdb.h>
+#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
-#ifdef Darwin
+#endif
+#ifdef HAVE_STDINT_H
 #include <stdint.h>
 #endif
 #include <sys/types.h>
+#ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
+#endif
 #include <sys/socket.h>
 #ifdef HAVE_SYS_FILIO_H
 #include <sys/filio.h>
@@ -43,7 +53,9 @@
 #include <net/if.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
+#ifdef HAVE_LIMITS_H
 #include <limits.h>
+#endif
 #include <setjmp.h>
 #include <ctype.h>
 #include <pwd.h>
@@ -53,6 +65,10 @@
 #include <time.h>
 #endif 
 
+#ifdef HAVE_SYS_CDEFS_H
+#include <sys/cdefs.h>
+#endif
+
 #ifdef __FreeBSD__
 #include <sys/param.h>
 #define socklen_t int
@@ -62,6 +78,10 @@
 #include <malloc.h>
 #endif
 
+#ifdef SWILL
+#include <swill.h>
+#endif
+
 #include "macros.h"
 #include "tot_constants.h"
 #include "tot_types.h"
@@ -84,6 +104,7 @@ struct ToT {
 	int debug; 		/* debugging level, 0 == no debugging output */
 	int port;		/* the port we listen at for requests */
 	int retry_interval;	/* how long to wait til retry forwarder */
+	int http_port;		/* the port we listen at for http requests */
 	/* boolean flags */
 	int ip4;		/* do we do IPv4 */
 	int ip6;		/* do we do IPv6 */
@@ -108,7 +129,6 @@ struct ToT {
 	struct in6_addr scoped_to[MAXPREFIXES];
 	int scoped_plen[MAXPREFIXES];
 #endif
-	u_char MSG_Buf[MAX_STREAM];	/* Buffer for TCP/UDP messages */
 };
 
 extern struct ToT T;
